@@ -33,17 +33,17 @@ try {
  $view->assign( 'canceled_jobs', Jobs_Model::count_Jobs( $dbSql->db_link, array( LAST_DAY, NOW), 'canceled') );
 
  // Stored files number 
- $view->assign( 'stored_files', $dbSql->translate->get_Number_Format( Jobs_Model::get_Stored_Files( $dbSql->db_link, array(FIRST_DAY, NOW) ) ) );
+ $view->assign( 'stored_files', CUtils::format_Number( Jobs_Model::getStoredFiles( $dbSql->db_link, array(FIRST_DAY, NOW) ) ) );
  
+ // Overall stored bytes
+ $view->assign( 'stored_bytes', CUtils::Get_Human_Size( Jobs_Model::getStoredBytes( $dbSql->db_link, array(FIRST_DAY, NOW) ) ) );
+
  // Database size
  $view->assign( 'database_size', Database_Model::get_Size( $dbSql->db_link, $dbSql->catalog_current_id ) );
-
- // Overall stored bytes
- $view->assign( 'stored_bytes', CUtils::Get_Human_Size( Jobs_Model::get_Stored_Bytes( $dbSql->db_link, array(FIRST_DAY, NOW) ) ) );
  
  // Total bytes and files stored over the last 24 hours
- $view->assign( 'bytes_last', CUtils::Get_Human_Size( Jobs_Model::get_Stored_Bytes( $dbSql->db_link, array(LAST_DAY, NOW) ) ) );
- $view->assign( 'files_last', $dbSql->translate->get_Number_Format( Jobs_Model::get_Stored_Files( $dbSql->db_link, array(LAST_DAY, NOW) ) ) );
+ $view->assign( 'bytes_last', CUtils::Get_Human_Size( Jobs_Model::getStoredBytes( $dbSql->db_link, array(LAST_DAY, NOW) ) ) );
+ $view->assign( 'files_last', CUtils::format_Number( Jobs_Model::getStoredFiles( $dbSql->db_link, array(LAST_DAY, NOW) ) ) );
 
  // Number of clients
  $view->assign('clients', Clients_Model::count($dbSql->db_link) );
@@ -56,20 +56,19 @@ try {
  $view->assign('incr_jobs', Jobs_Model::count_Jobs( $dbSql->db_link, array( LAST_DAY, NOW), null, J_INCR) );
  $view->assign('diff_jobs', Jobs_Model::count_Jobs( $dbSql->db_link, array( LAST_DAY, NOW), null, J_DIFF) );
  $view->assign('full_jobs', Jobs_Model::count_Jobs( $dbSql->db_link, array( LAST_DAY, NOW), null, J_FULL) );
- 
- // Volumes size
- $volumes_size = $dbSql->getVolumesSize();
+
+ // Volumes disk usage
+ $volumes_size = Volumes_Model::getDiskUsage($dbSql->db_link);
  $view->assign('volumes_size', CUtils::Get_Human_Size( $volumes_size ) );
 
  // Pools count
- //$view->assign('pools_nb', $dbSql->countPools() );
  $view->assign( 'pools_nb', Pools_Model::count( $dbSql->db_link ) );
 
  // Backup Job list
  $view->assign('jobs_list', Jobs_Model::get_Jobs_List($dbSql->db_link) );
  
  // Clients list
- $view->assign('clients_list', $dbSql->get_Clients());
+ $view->assign('clients_list', Clients_Model::getClients($dbSql->db_link) );
 
  // Count volumes
  $view->assign('volumes_nb', Volumes_Model::count($dbSql->db_link) );
@@ -81,7 +80,7 @@ try {
  $jobs_status_data = array();
 
  foreach ($jobs_status as $status) {
-	$jobs_count 		= Jobs_Model::count_Jobs( $dbSql->db_link, array( LAST_DAY, NOW), $status);
+	$jobs_count 		= Jobs_Model::count_Jobs( $dbSql->db_link, array( LAST_DAY, NOW), strtolower($status) );
 	$jobs_status_data[] = array($status, $jobs_count );
  }
  
@@ -154,7 +153,7 @@ try {
  $days = CTimeUtils::getLastDaysIntervals(7);
 
  foreach ($days as $day) {
-    $stored_bytes 			= CUtils::Get_Human_Size( Jobs_Model::get_Stored_Bytes( $dbSql->db_link, array($day['start'], $day['end']) ), 1, 'GB', false );
+    $stored_bytes 			= CUtils::Get_Human_Size( Jobs_Model::getStoredBytes( $dbSql->db_link, array($day['start'], $day['end']) ), 1, 'GB', false );
     $days_stored_bytes[] 	= array(date("m-d", $day['start']), $stored_bytes);
  } 
  
@@ -209,7 +208,10 @@ try {
  }catch (Exception $e) {
     CErrorHandler::displayError($e);
  }
-
+ 
+ // Set page name
+ $view->assign('page_name', 'Dashboard');
+ 
  // Render template
  $view->render('index.tpl');
 ?>
